
1.2.2 (2018-07-23)
###################

Changes since 1.2.1 (2018-07-21).

Bug Fixes
$$$$$$$$$$

* Closes `#501 <https://github.com/biocommons/hgvs/issues/501/>`_: Add c_to_p support for inversion (`#502 <https://github.com/biocommons/hgvs/issues/502/>`_)
